summaryrefslogtreecommitdiffstats
path: root/tdecore/kstandarddirs.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/kstandarddirs.h')
-rw-r--r--tdecore/kstandarddirs.h72
1 files changed, 36 insertions, 36 deletions
diff --git a/tdecore/kstandarddirs.h b/tdecore/kstandarddirs.h
index 77fec4efd..7cdf44e37 100644
--- a/tdecore/kstandarddirs.h
+++ b/tdecore/kstandarddirs.h
@@ -26,10 +26,10 @@
#include <tqstring.h>
#include <tqdict.h>
#include <tqstringlist.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
-class KConfig;
-class KStandardDirsPrivate;
+class TDEConfig;
+class TDEStandardDirsPrivate;
/**
* @short Site-independent access to standard KDE directories.
@@ -45,12 +45,12 @@ class KStandardDirsPrivate;
* and applications always refer to a file with a resource type
* (e.g. icon) and a filename (e.g. khexdit.xpm). In an ideal world
* the application would make no assumption where this file is and
* leave it up to KStandardDirs::findResource("apps", "Home.desktop")
* to apply this knowledge to return /opt/kde/share/applnk/Home.desktop
* or ::locate("data", "kgame/background.jpg") to return
* /opt/kde/share/apps/kgame/background.jpg
*
* The main idea behind KStandardDirs is that there are several
* toplevel prefixes below which the files lie. One of these prefixes is
* the one where the user installed tdelibs, one is where the
* application was installed, and one is $HOME/.trinity, but there
@@ -61,7 +61,7 @@ class KStandardDirsPrivate;
* So the search algorithm basically appends to each prefix each registered
* suffix and tries to locate the file there.
* To make the thing even more complex, it's also possible to register
* absolute paths that KStandardDirs looks up after not finding anything
* in the former steps. They can be useful if the user wants to provide
* specific directories that aren't in his $HOME/.trinity directory for,
* for example, icons.
@@ -75,9 +75,9 @@ class KStandardDirsPrivate;
* @li data - Where applications store data.
* @li exe - Executables in $prefix/bin. findExe() for a function that takes $PATH into account.
* @li html - HTML documentation.
- * @li icon - Icons, see KIconLoader.
+ * @li icon - Icons, see TDEIconLoader.
* @li lib - Libraries.
- * @li locale - Translation files for KLocale.
+ * @li locale - Translation files for TDELocale.
* @li mime - Mime types.
* @li module - Module (dynamically loaded library).
* @li qtplugins - Qt plugins (dynamically loaded objects for Qt)
@@ -91,19 +91,19 @@ class KStandardDirsPrivate;
* @li socket - UNIX Sockets (specific for both current host and current user)
* @li emoticons - Emoticons themes (Since KDE 3.4)
*
- * A type that is added by the class KApplication if you use it, is
+ * A type that is added by the class TDEApplication if you use it, is
* appdata. This one makes the use of the type data a bit easier as it
* appends the name of the application.
* So while you had to ::locate("data", "appname/filename") so you can
* also write ::locate("appdata", "filename") if your KApplication instance
* is called "appname" (as set via KApplication's constructor or KAboutData, if
* you use the global KStandardDirs object KGlobal::dirs()).
* Please note though that you cannot use the "appdata"
* type if you intend to use it in an applet for Kicker because 'appname' would
* be "Kicker" instead of the applet's name. Therefore, for applets, you've got
* to work around this by using ::locate("data", "appletname/filename").
*
* <b>KStandardDirs supports the following environment variables:</b>
*
* @li TDEDIRS: This may set an additional number of directory prefixes to
* search for resources. The directories should be separated
@@ -120,20 +120,20 @@ class KStandardDirsPrivate;
* home directory of root, usually "/root/.trinity".
* Note that the setting of $HOME is ignored in this case.
*
- * @see KGlobalSettings
+ * @see TDEGlobalSettings
*/
-class TDECORE_EXPORT KStandardDirs
+class TDECORE_EXPORT TDEStandardDirs
{
public:
/**
* KStandardDirs' constructor. It just initializes the caches.
**/
- KStandardDirs( );
+ TDEStandardDirs( );
/**
- * KStandardDirs' destructor.
+ * TDEStandardDirs' destructor.
*/
- virtual ~KStandardDirs();
+ virtual ~TDEStandardDirs();
/**
* Adds another search dir to front of the @p fsstnd list.
@@ -175,7 +175,7 @@ public:
* The later a suffix is added, the higher its priority. Note, that the
* suffix should end with / but doesn't have to start with one (as prefixes
* should end with one). So adding a suffix for app_pics would look
- * like KGlobal::dirs()->addResourceType("app_pics", "share/app/pics");
+ * like TDEGlobal::dirs()->addResourceType("app_pics", "share/app/pics");
*
* @param type Specifies a short descriptive string to access
* files of this type.
@@ -211,7 +211,7 @@ public:
*
* The filename should be a filename relative to the base dir
* for resources. So is a way to get the path to libtdecore.la
* to findResource("lib", "libtdecore.la"). KStandardDirs will
* then look into the subdir lib of all elements of all prefixes
* ($TDEDIRS) for a file libtdecore.la and return the path to
* the first one it finds (e.g. /opt/kde/lib/libtdecore.la)
@@ -414,7 +414,7 @@ public:
* It's a series of addResourceTypes()
* and addPrefix() calls.
* You normally wouldn't call this function because it's called
* for you from KGlobal.
*/
void addKDEDefaults();
@@ -427,7 +427,7 @@ public:
* @return true if new config paths have been added
* from @p config.
**/
- bool addCustomized(KConfig *config);
+ bool addCustomized(TDEConfig *config);
/**
* This function is used internally by almost all other function as
@@ -443,7 +443,7 @@ public:
TQStringList resourceDirs(const char *type) const;
/**
* This function will return a list of all the types that KStandardDirs
* supports.
*
* @return All types that KDE supports
@@ -545,7 +545,7 @@ public:
TQString kfsstnd_xdg_data_prefixes();
/**
* Returns the toplevel directory in which KStandardDirs
* will store things. Most likely $HOME/.trinity
* Don't use this function if you can use locateLocal
* @return the toplevel directory
@@ -617,13 +617,13 @@ public:
mutable TQDict<TQString> savelocations;
// Disallow assignment and copy-construction
- KStandardDirs( const KStandardDirs& );
- KStandardDirs& operator= ( const KStandardDirs& );
+ TDEStandardDirs( const TDEStandardDirs& );
+ TDEStandardDirs& operator= ( const TDEStandardDirs& );
bool addedCustoms;
- class KStandardDirsPrivate;
- KStandardDirsPrivate *d;
+ class TDEStandardDirsPrivate;
+ TDEStandardDirsPrivate *d;
void checkConfig() const;
void applyDataRestrictions(const TQString &) const;
@@ -696,14 +696,14 @@ public:
**/
/*!
- * \relates KStandardDirs
+ * \relates TDEStandardDirs
* This function is just for convenience. It simply calls
- *instance->dirs()->\link KStandardDirs::findResource() findResource\endlink(type, filename).
+ *instance->dirs()->\link TDEStandardDirs::findResource() findResource\endlink(type, filename).
**/
-TDECORE_EXPORT TQString locate( const char *type, const TQString& filename, const KInstance* instance = KGlobal::instance() );
+TDECORE_EXPORT TQString locate( const char *type, const TQString& filename, const TDEInstance* instance = TDEGlobal::instance() );
/*!
- * \relates KStandardDirs
+ * \relates TDEStandardDirs
* This function is much like locate. However it returns a
* filename suitable for writing to. No check is made if the
* specified filename actually exists. Missing directories
@@ -711,10 +711,10 @@ TDECORE_EXPORT TQString locate( const char *type, const TQString& filename, cons
* specific file, filename must have a trailing slash.
*
**/
-TDECORE_EXPORT TQString locateLocal( const char *type, const TQString& filename, const KInstance* instance = KGlobal::instance() );
+TDECORE_EXPORT TQString locateLocal( const char *type, const TQString& filename, const TDEInstance* instance = TDEGlobal::instance() );
/*!
- * \relates KStandardDirs
+ * \relates TDEStandardDirs
* This function is much like locate. No check is made if the
* specified filename actually exists. Missing directories
* are created if @p createDir is true. If filename is only
@@ -722,7 +722,7 @@ TDECORE_EXPORT TQString locateLocal( const char *type, const TQString& filename,
* filename must have a trailing slash.
*
**/
-TDECORE_EXPORT TQString locateLocal( const char *type, const TQString& filename, bool createDir, const KInstance* instance = KGlobal::instance() );
+TDECORE_EXPORT TQString locateLocal( const char *type, const TQString& filename, bool createDir, const TDEInstance* instance = TDEGlobal::instance() );
/*! @} */
@@ -45,12 +45,12 @@ class KStandardDirsPrivate;
* (e.g. icon) and a filename (e.g. khexdit.xpm). In an ideal world
* the application would make no assumption where this file is and
- * leave it up to KStandardDirs::findResource("apps", "Home.desktop")
+ * leave it up to TDEStandardDirs::findResource("apps", "Home.desktop")
* to apply this knowledge to return /opt/kde/share/applnk/Home.desktop
* or ::locate("data", "kgame/background.jpg") to return
@@ -45,12 +45,12 @@ class KStandardDirsPrivate;
* /opt/kde/share/apps/kgame/background.jpg
*
- * The main idea behind KStandardDirs is that there are several
+ * The main idea behind TDEStandardDirs is that there are several
* toplevel prefixes below which the files lie. One of these prefixes is
* the one where the user installed tdelibs, one is where the
@@ -61,7 +61,7 @@ class KStandardDirsPrivate;
* suffix and tries to locate the file there.
* To make the thing even more complex, it's also possible to register
- * absolute paths that KStandardDirs looks up after not finding anything
+ * absolute paths that TDEStandardDirs looks up after not finding anything
* in the former steps. They can be useful if the user wants to provide
* specific directories that aren't in his $HOME/.trinity directory for,
@@ -91,19 +91,19 @@ class KStandardDirsPrivate;
* appends the name of the application.
* So while you had to ::locate("data", "appname/filename") so you can
- * also write ::locate("appdata", "filename") if your KApplication instance
- * is called "appname" (as set via KApplication's constructor or KAboutData, if
- * you use the global KStandardDirs object KGlobal::dirs()).
+ * also write ::locate("appdata", "filename") if your TDEApplication instance
+ * is called "appname" (as set via TDEApplication's constructor or TDEAboutData, if
+ * you use the global TDEStandardDirs object TDEGlobal::dirs()).
* Please note though that you cannot use the "appdata"
* type if you intend to use it in an applet for Kicker because 'appname' would
@@ -91,19 +91,19 @@ class KStandardDirsPrivate;
* to work around this by using ::locate("data", "appletname/filename").
*
- * <b>KStandardDirs supports the following environment variables:</b>
+ * <b>TDEStandardDirs supports the following environment variables:</b>
*
* @li TDEDIRS: This may set an additional number of directory prefixes to
@@ -120,20 +120,20 @@ class KStandardDirsPrivate;
public:
/**
- * KStandardDirs' constructor. It just initializes the caches.
+ * TDEStandardDirs' constructor. It just initializes the caches.
**/
@@ -211,7 +211,7 @@ public:
* The filename should be a filename relative to the base dir
* for resources. So is a way to get the path to libtdecore.la
- * to findResource("lib", "libtdecore.la"). KStandardDirs will
+ * to findResource("lib", "libtdecore.la"). TDEStandardDirs will
* then look into the subdir lib of all elements of all prefixes
* ($TDEDIRS) for a file libtdecore.la and return the path to
@@ -414,7 +414,7 @@ public:
* and addPrefix() calls.
* You normally wouldn't call this function because it's called
- * for you from KGlobal.
+ * for you from TDEGlobal.
*/
void addKDEDefaults();
@@ -443,7 +443,7 @@ public:
TQStringList resourceDirs(const char *type) const;
/**
- * This function will return a list of all the types that KStandardDirs
+ * This function will return a list of all the types that TDEStandardDirs
* supports.
*
@@ -545,7 +545,7 @@ public:
TQString kfsstnd_xdg_data_prefixes();
/**
- * Returns the toplevel directory in which KStandardDirs
+ * Returns the toplevel directory in which TDEStandardDirs
* will store things. Most likely $HOME/.trinity
* Don't use this function if you can use locateLocal